//#define XERR
#include "incidence.ih"

Incidence::Incidence(Scenario const &scenario)
:
    d_scenario(scenario)
{
    set();                                  // set the parameters

                                            // room for the age-risks per 
    d_tumorRisk.resize(d_params.size());    // carrier category

    for (auto &vect: d_tumorRisk)           // resize for all ages
        vect.resize(END_AGE);

    setTumorRisk();
}
